==> zio-aws-rds_2.12-5.17.129.2-sources.jar: zio/aws/rds/model/CreateDbProxyEndpointResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateDbProxyEndpointResponse(
    dbProxyEndpoint: scala.Option[zio.aws.rds.model.DBProxyEndpoint] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.CreateDbProxyEndpointResponse = {
    import CreateDbProxyEndpointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.CreateDbProxyEndpointResponse
      .builder()
      .optionallyWith(dbProxyEndpoint.map(value => value.buildAwsValue()))(
        _.dbProxyEndpoint
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.CreateDbProxyEndpointResponse.ReadOnly =
    zio.aws.rds.model.CreateDbProxyEndpointResponse.wrap(buildAwsValue())
}
object CreateDbProxyEndpointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.CreateDbProxyEndpointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.CreateDbProxyEndpointResponse =
      zio.aws.rds.model.CreateDbProxyEndpointResponse(
        dbProxyEndpoint.map(value => value.asEditable)
      )
    def dbProxyEndpoint
        : scala.Option[zio.aws.rds.model.DBProxyEndpoint.ReadOnly]
    def getDbProxyEndpoint
        : ZIO[Any, AwsError, zio.aws.rds.model.DBProxyEndpoint.ReadOnly] =
      AwsError.unwrapOptionField("dbProxyEndpoint", dbProxyEndpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.CreateDbProxyEndpointResponse
  ) extends zio.aws.rds.model.CreateDbProxyEndpointResponse.ReadOnly {
    override val dbProxyEndpoint
        : scala.Option[zio.aws.rds.model.DBProxyEndpoint.ReadOnly] = scala
      .Option(impl.dbProxyEndpoint())
      .map(value => zio.aws.rds.model.DBProxyEndpoint.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.CreateDbProxyEndpointResponse
  ): zio.aws.rds.model.CreateDbProxyEndpointResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-rds_2.13-5.19.33.1-sources.jar: zio/aws/rds/model/CreateDbProxyEndpointResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateDbProxyEndpointResponse(
    dbProxyEndpoint: Optional[zio.aws.rds.model.DBProxyEndpoint] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.CreateDbProxyEndpointResponse = {
    import CreateDbProxyEndpointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.CreateDbProxyEndpointResponse
      .builder()
      .optionallyWith(dbProxyEndpoint.map(value => value.buildAwsValue()))(
        _.dbProxyEndpoint
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.CreateDbProxyEndpointResponse.ReadOnly =
    zio.aws.rds.model.CreateDbProxyEndpointResponse.wrap(buildAwsValue())
}
object CreateDbProxyEndpointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.CreateDbProxyEndpointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.CreateDbProxyEndpointResponse =
      zio.aws.rds.model.CreateDbProxyEndpointResponse(
        dbProxyEndpoint.map(value => value.asEditable)
      )
    def dbProxyEndpoint: Optional[zio.aws.rds.model.DBProxyEndpoint.ReadOnly]
    def getDbProxyEndpoint
        : ZIO[Any, AwsError, zio.aws.rds.model.DBProxyEndpoint.ReadOnly] =
      AwsError.unwrapOptionField("dbProxyEndpoint", dbProxyEndpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.CreateDbProxyEndpointResponse
  ) extends zio.aws.rds.model.CreateDbProxyEndpointResponse.ReadOnly {
    override val dbProxyEndpoint
        : Optional[zio.aws.rds.model.DBProxyEndpoint.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbProxyEndpoint())
        .map(value => zio.aws.rds.model.DBProxyEndpoint.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.CreateDbProxyEndpointResponse
  ): zio.aws.rds.model.CreateDbProxyEndpointResponse.ReadOnly = new Wrapper(
    impl
  )
}
